==> apache-kylin-3.0.0-source-release.zip: apache-kylin-3.0.0/stream-core/src/main/java/org/apache/kylin/stream/core/query/IStreamingSearchResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kylin.stream.core.query;

import java.io.Closeable;
import java.io.IOException;
import java.util.Iterator;

import org.apache.kylin.stream.core.storage.Record;

import com.google.common.collect.Iterators;

public interface IStreamingSearchResult extends Iterable<Record>, Closeable {
    IStreamingSearchResult EMPTY_RESULT = new IStreamingSearchResult() {

        @Override
        public void close() throws IOException {
        }

        @Override
        public Iterator<Record> iterator() {
            return Iterators.emptyIterator();
        }

        @Override
        public void startRead() {
        }

        @Override
        public void endRead() {
        }
    };

    /**
     * start to read data
     */
    void startRead();

    /**
     * finish reading data
     */
    void endRead();
}

==> apache-kylin-3.1.3-source-release.zip: apache-kylin-3.1.3/stream-core/src/main/java/org/apache/kylin/stream/core/query/IStreamingSearchResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kylin.stream.core.query;

import java.io.Closeable;
import java.io.IOException;
import java.util.Collections;
import java.util.Iterator;

import org.apache.kylin.stream.core.storage.Record;


public interface IStreamingSearchResult extends Iterable<Record>, Closeable {
    IStreamingSearchResult EMPTY_RESULT = new IStreamingSearchResult() {

        @Override
        public void close() throws IOException {
        }

        @Override
        public Iterator<Record> iterator() {
            return Collections.emptyIterator();
        }

        @Override
        public void startRead() {
        }

        @Override
        public void endRead() {
        }
    };

    /**
     * start to read data
     */
    void startRead();

    /**
     * finish reading data
     */
    void endRead();
}
